/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2008 Shintaro Fujiwara 
 * shintaro.fujiwara@gmail.com
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */
#include <qapplication.h>

#include "downloader.h"

int main(int argc, char *argv[])
{
	QApplication app(argc, argv);
	QUrl url("ftp://ftp.riken.jp/Linux/fedora/");
	QString version;
	if (argc >= 2){
		url = argv[1];
		version = argv[2];
	}
	Downloader downloader(url, version);
	QObject::connect(&downloader, SIGNAL(finished()),
		&app, SLOT(quit()));
	return app.exec();
}
